@@ -4,15 +4,20 @@ import argparse
 import subprocess
 import openai
 import os
+from urllib.parse import quote
 from simple_term_menu import TerminalMenu
+import platform
 
 
 def main():
     parser = argparse.ArgumentParser(prog='copilot', description='Terminal Copilot')
     parser.add_argument('command', type=str, nargs='+',
                         help='Describe the command you are looking for.')
+    parser.add_argument('-a', '--with-aliases', action='store_true',
+                        help='include aliases in the prompt')
     parser.add_argument('-v', '--verbose', action='store_true',
                         help='increase output verbosity')
+
     args = parser.parse_args()
 
     if args.verbose:
@@ -28,8 +33,11 @@ def main():
         if key in os.environ:
             environs += f"{key}={os.environ[key]}\n"
 
+    shell = os.environ["SHELL"]
+    operating_system = platform.system()
+
     prompt = f"""
-You are an AI Terminal Copilot. Your job is to help users find the right terminal command in a zsh shell on mac os.
+You are an AI Terminal Copilot. Your job is to help users find the right terminal command in a {shell} on {operating_system}.
 
 The user is asking for the following command:
 '{" ".join(args.command)}'
@@ -40,6 +48,13 @@ That directory contains the following files:
 {subprocess.run(["ls"], capture_output=True).stdout.decode("utf-8")}
 The user has several environment variables set, some of which are:
 {environs}
+"""
+    if args.with_aliases:
+        prompt += f"""
+The user has the following aliases set:
+{subprocess.run(["alias"], capture_output=True, shell=True).stdout.decode("utf-8")}
+"""
+    prompt += """
 
 The command the user is looking for is:
 `
@@ -70,7 +85,7 @@ The command the user is looking for is:
     # strip all whitespace from the response start or end
     cmd = response.choices[0].text.strip()
     print(f"\033[94m> {cmd}\033[0m")
-    options = ["execute", "copy", "explain"]
+    options = ["execute", "copy", "explainshell"]
     terminal_menu = TerminalMenu(options)
     menu_entry_index = terminal_menu.show()
     if menu_entry_index == 0:
@@ -79,5 +94,6 @@ The command the user is looking for is:
         print("> copied")
         subprocess.run(["pbcopy"], input=cmd, encoding="utf-8")
     elif menu_entry_index == 2:
-        print("> explain")
-        subprocess.run(["open", "https://explainshell.com/explain?cmd=" + cmd])
\ No newline at end of file
+        link = "https://explainshell.com/explain?cmd=" + quote(cmd)
+        print("> explainshell: " + link)
+        subprocess.run(["open", "https://explainshell.com/explain?cmd=" + quote(cmd)])
\ No newline at end of file
